@@ -6,6 +6,9 @@
 #' \code{\link{bvec}}.
 #' @param ci a numeric between 0 and 1 specifying the probability of the credible band.
 #' Defaults to 0.95.
+#' @param period integer. Index of the period of a TVP VEC, for which a summary should be generated.
+#' Only used for TVP models. Default is \code{NULL} so that only the most recent time period
+#' is used.
 #' @param x an object of class \code{"summary.bvec"}, usually, a result of a call to
 #' \code{\link{summary.bvec}}.
 #' @param digits the number of significant digits to use when printing.
@@ -20,14 +23,29 @@
 #' \item{specifications}{a list containing information on the model specification.}
 #'
 #' @export
-summary.bvec <- function(object, ci = .95, ...){
+summary.bvec <- function(object, ci = .95, period = NULL, ...){
+  
   # Number of endogenous variables
-  k <- object$specifications$dims["K"]
+  k <- object[["specifications"]][["dims"]][["K"]]
+  tt <- NROW(object[["y"]])
+  tvp <- object[["specifications"]][["tvp"]]
+  if (any(unlist(tvp))) {
+    if (is.null(period)) {
+      period <- tt
+    } else {
+      if (period > tt | period < 1) {
+        stop("Implausible specification of argument 'period'.")
+      }
+    }
+    period_long <- stats::time(object[["y"]])[period]
+  } else {
+    period_long <- NULL
+  }
   
   # Extract variable names
   dim_names <- list(NULL, NULL)
-  if (!is.null(object$y)) {
-    y_names <- dimnames(object$y)[[2]]
+  if (!is.null(object[["y"]])) {
+    y_names <- dimnames(object[["y"]])[[2]]
   } else {
     y_names <- paste("d.y", 1:k, sep = "")
   }
@@ -79,7 +97,14 @@ summary.bvec <- function(object, ci = .95, ...){
   } else {
     if (!is.null(object[["Upsilon"]])) {
       m <- NCOL(object[["Upsilon"]]) / k
-      x_names <- c(x_names, paste("d.x", 1:m, sep = ""))
+      if (nchar(m) > 2) {
+        m_max <- nchar(m)
+      } else {
+        m_max <- 2
+      }
+      i_temp <- paste0(rep(paste0(rep(0, m_max), collapse = ""), m), 0:(m - 1))
+      i_temp <- substring(i_temp, nchar(i_temp) - m_max + 1, nchar(i_temp))
+      x_names <- c(x_names, paste0("d.x.l", i_temp))
     }
   }
   if (!is.null(object[["x_d"]])) {
@@ -115,7 +140,11 @@ summary.bvec <- function(object, ci = .95, ...){
   vars <- c("Pi", "Pi_x", "Pi_d", "Gamma", "Upsilon", "C", "A0")
   for (i in vars) {
     if (!is.null(object[[i]])) {
-      temp <- summary(object[[i]], quantiles = c(ci_low, .5, ci_high))
+      if (tvp[[i]]) {
+        temp <- summary(object[[i]][[period]], quantiles = c(ci_low, .5, ci_high))
+      } else {
+        temp <- summary(object[[i]], quantiles = c(ci_low, .5, ci_high)) 
+      }
       if ("numeric" %in% class(temp$statistics)) {
         means <- cbind(means, matrix(temp$statistics["Mean"], k))
         sds <- cbind(sds, matrix(temp$statistics["SD"], k))
@@ -138,7 +167,11 @@ summary.bvec <- function(object, ci = .95, ...){
         if (var_temp %in% names(object)) {
           incl <- cbind(incl, matrix(colMeans(object[[var_temp]]), k))
         } else {
-          incl <- cbind(incl, matrix(rep(NA_real_, ncol(object[[i]])), k))
+          if (tvp[[i]]) {
+            incl <- cbind(incl, matrix(rep(NA_real_, ncol(object[[i]][[1]])), k))  
+          } else {
+            incl <- cbind(incl, matrix(rep(NA_real_, ncol(object[[i]])), k))
+          }
         }
       }
     }
@@ -164,14 +197,18 @@ summary.bvec <- function(object, ci = .95, ...){
                                      q_upper = q_high))
   
   if (use_incl) {
-    result$coefficients$lambda = incl
+    result[["coefficients"]][["lambda"]] = incl
   }
   
   # Error coefficients
   dim_names <- list(y_names, y_names)
   
   if (!is.null(object[["Sigma"]])) {
-    temp <- summary(object$Sigma, quantiles = c(ci_low, .5, ci_high))
+    if (tvp[["Sigma"]]) {
+      temp <- summary(object$Sigma[[period]], quantiles = c(ci_low, .5, ci_high))
+    } else {
+      temp <- summary(object$Sigma, quantiles = c(ci_low, .5, ci_high)) 
+    }
     if (k == 1) {
       means <- matrix(temp$statistics["Mean"], k)
       sds <- matrix(temp$statistics["SD"], k)
@@ -198,26 +235,24 @@ summary.bvec <- function(object, ci = .95, ...){
     dimnames(median) <- dim_names
     dimnames(q_high) <- dim_names
     
-    result$sigma <- list(means = means,
-                         median = median,
-                         sd = sds,
-                         naivesd = naive_sd,
-                         tssd = ts_sd,
-                         q_lower = q_low,
-                         q_upper = q_high)
+    result[["sigma"]] <- list(means = means,
+                              median = median,
+                              sd = sds,
+                              naivesd = naive_sd,
+                              tssd = ts_sd,
+                              q_lower = q_low,
+                              q_upper = q_high)
     
     if ("Sigma_lambda" %in% names(object)) {
-      incl <- diag(NA_real_, k)
-      means <- colMeans(object$Sigma_lambda)
-      incl[upper.tri(incl)] <- means
-      incl[lower.tri(incl)] <- means
+      incl <- matrix(colMeans(object[["Sigma_lambda"]]), k)
       dimnames(incl) <- dim_names
-      result$sigma$lambda = incl
+      result[["sigma"]][["lambda"]] = incl
     }
   }
   
-  result$specifications <- object$specifications
-  result$specifications$ci <- paste(c(ci_low, ci_high) * 100, "%", sep = "")
+  result[["specifications"]] <- object[["specifications"]]
+  result[["specifications"]][["ci"]] <- paste(c(ci_low, ci_high) * 100, "%", sep = "")
+  result[["specifications"]][["period"]] <- period_long
   
   class(result) <- "summary.bvec"
   return(result)
