@@ -336,7 +336,7 @@ Rcpp::List bvecalg(Rcpp::List object) {
     sigma_i = omega_i;
   }
   diag_sigma_i = arma::kron(diag_tt, sigma_i);
-  if (covar | sv) {
+  if (covar || sv) {
     diag_omega_i = diag_sigma_i;
   }
   g_i = sigma_i;
@@ -592,7 +592,7 @@ Rcpp::List bvecalg(Rcpp::List object) {
       
       // Draw variances  
       for (int i = 0; i < k; i++) {
-        h.col(i) = bvartools::stoch_vol(u.row(i).t(), h.col(i), sigma_h(i), h_init(i));
+        h.col(i) = bvartools::stoch_vol(u.row(i).t(), h.col(i), sigma_h(i), h_init(i), .0001);
       }
       diag_omega_i.diag() = 1 / exp(arma::vectorise(h.t()));
       if (covar) {
